pub struct LayoutShape {
pub fields: FieldsShape,
pub variants: VariantsShape,
pub value_repr: ValueRepr,
pub abi_align: Align,
pub size: MachineSize,
}Expand description
The layout of a type, including its size, alignment, field offsets, and backend representation.
Fields
fields: FieldsShapeThe fields location within the layout
variants: VariantsShapeEncodes information about multi-variant layouts.
Even with Multiple variants, a layout still has its own fields! Those are then
shared between all variants.
To access all fields of this layout, both fields and the fields of the active variant
must be taken into account.
value_repr: ValueReprA hint for how backends should represent this type: as a scalar, vector, or aggregate.
abi_align: AlignThe ABI mandated alignment in bytes.
size: MachineSizeThe size of this layout in bytes.
Implementations